Changelog
=========

1.0.4
-----
- Update settings.rst
- Update message handler call and base message handlers to accept the request object
- Update flake8 and pycodestyle to allow for longer lines.
- Update .editorconfig to allow longer lines.
- Fix decoration of logging_view.

1.0.3
-----
- Ensure get_message is CSRF exempt.
- get_message view only allows POST requests.

1.0.2
-----
- Update README.rst
- Clarify url pattern in README.rst moving carat to more logical place in example

1.0.1
-----
- Remove Herodotus dependency
- Omit latex glossary
- Stringify log message

1.0.0
-----
- Initial version
